Module: Nagios::MkLiveStatus::QueryHelper::Comparator
- Included in:
- Filter::Attr, Nagios::MkLiveStatus::QueryHelper, Stats::Attr, Wait::Attr
- Defined in:
- lib/nagios_mklivestatus/query_helper.rb
Overview
This module contains all the comparators which can be used by stats, wait and filter. It provides a method that helps you to get a list of all operators
- Author
Esco-lan Team (mailto:[email protected])
- Copyright
Copyright (c) 2012 GIP RECIA
- License
General Public Licence
Constant Summary collapse
- EQUAL =
equal filter or empty list : =
"="- SUBSTR =
regular expression like /
/ : ~ "~"- EQUAL_IGNCASE =
equal ignore case : =~
"=~"- SUBSTR_IGNCASE =
regular expression ignoring case : ~~
"~~"- LESSER =
less than in alphabetical order : <
"<"- GREATER =
greater than in alphabetical order : >
">"- LESSER_EQUAL =
less or equal to in alphabetical order : <=
"<="- GREATER_EQUAL =
less or equal to in alphabetical order or list contains : >=
">="- NOT_EQUAL =
not equals to : !=
"!="- NOT_SUBSTR =
not matching substring : !~
"!~"- NOT_EQUAL_IGNCASE =
not equals to ignoring case : !=~
"!=~"- NOT_SUBSTR_IGNCASE =
not matching substring ignoring case : !~~
"!~~"
Instance Method Summary collapse
-
#get_all_comparators ⇒ Object
get all the comparator constants values.
Instance Method Details
#get_all_comparators ⇒ Object
get all the comparator constants values
180 181 182 183 184 185 186 187 |
# File 'lib/nagios_mklivestatus/query_helper.rb', line 180 def get_all_comparators all=[] Comparator.constants(false).each do |const| all.push Comparator.const_get(const) end return all end |