Module: Nagios::MkLiveStatus::QueryHelper::Deviation
- Included in:
- Nagios::MkLiveStatus::QueryHelper, Stats::Attr
- Defined in:
- lib/nagios_mklivestatus/query_helper.rb
Overview
This module contains all the deviations which can be used by stats. It provides a method that helps you to get a list of all operators.
- Author
Esco-lan Team (mailto:[email protected])
- Copyright
Copyright (c) 2012 GIP RECIA
- License
General Public Licence
Constant Summary collapse
- SUM =
sum deviation
"sum"- SUMINV =
suminv deviation
"suminv"- MIN =
min deviation
"min"- MAX =
max deviation
"max"- AVG =
avg deviation
"avg"- AVGINV =
avginv deviation
"avginv"- STD =
std deviation
"std"
Instance Method Summary collapse
-
#get_all_deviations ⇒ Object
get all the deviation constants values.