Module: Nagios::MkLiveStatus::QueryHelper::Trigger
- Included in:
- Nagios::MkLiveStatus::QueryHelper, Wait::Trigger
- Defined in:
- lib/nagios_mklivestatus/query_helper.rb
Overview
This module contains all the trigger which can be used by wait. It provides a method that helps you to get a list of all triggers.
- Author
Esco-lan Team (mailto:[email protected])
- Copyright
Copyright (c) 2012 GIP RECIA
- License
General Public Licence
Constant Summary collapse
- CHECK =
a service or host check has been executed
"check"- STATE =
the state of a host or service has changed
"state"- LOG =
a new message has been logged into nagios.log
"log"- DOWNTIME =
a downtime has been set or removed
"downtime"- COMMENT =
a comment has been set or removed
"comment"- COMMAND =
an external command has been executed
"command"- ALL =
any of the upper events happen (this is the default)
"all"
Instance Method Summary collapse
-
#get_all_triggers ⇒ Object
get all the trigger constants values.